@@ -396,29 +396,27 @@ class HttpRequest:
         #    file_object = StringIO.StringIO(self.request.body)
         #    gzipper = gzip.GzipFile(fileobj=file_object)
         #    data = gzipper.read()gzip
-        self.raw_body = None if http_method not in [HttpMethod.POST, HttpMethod.PUT] \
-            else None if body is None or len(body) == 0 \
+        #
+        #
+        # @note: We keep the body message even for HTTP method other than POST
+        #     and PUT.  There are HTTP requests with method GET that need to
+        #     pass sensitive data to check a resource's status (e.g., password
+        #     reset request, providing a nonce).  HTTP request's query string
+        #     is not encrypted, and therefore passing sensitive data in the
+        #     query would allow man-in-the-middle (MITM) attack.
+        self.raw_body = None if body is None or len(body) == 0 \
             else zlib.decompress(body, 16 + zlib.MAX_WBITS) if headers.get('Content-Encoding') == 'gzip' \
             else body
 
-        #
         content_type = self.headers.get('Content-Type')
         if content_type:
             content_type_parts = [part.strip() for part in content_type.split(';')]
             media_type, encoding = content_type_parts if len(content_type_parts) == 2 else (content_type_parts[0], None)
 
-        print("########### MESSAGE BODY ##########")
-        print(self.raw_body)
-        print(content_type)
-        print(content_type and media_type)
-
         self.body = None if self.raw_body is None \
             else json.loads(self.raw_body) if content_type and media_type == 'application/json' \
             else self.raw_body
 
-        print("########### MESSAGE BODY ##########")
-        print(self.body)
-
     # def _prepare(self):
     #     """
     #     Complete the instantiation of the HTTP request object.  This method
@@ -684,10 +682,6 @@ class HttpRequest:
         # the message body, depending on the argument passing.
         is_argument_defined = False
 
-        print("########## ARGUMENT PASSING ##########")
-        print(str(argument_passing))
-        print(self.body)
-
         if argument_passing == HttpRequest.ArgumentPassing.query_string:
             if name in self.arguments:
                 is_argument_defined = True
